@@ -43,6 +43,7 @@ def main(
     client = get_client()
     client.register_worker_plugin(SettingsPlugin(stitcher, config))
     update_config(stitcher, config)
+    logger.info("Using settings %s", Settings.__repr__())
 
     initialize(output_path)
 
@@ -75,11 +76,18 @@ def main(
 
             create_tileset(output_path, "tileset")
 
-        if "bead_detect" in recipes:
+        if "bead_detect2" in recipes:
             logger.info("Running bead_detection recipe")
             from ..bead_detect.runner import bead_detect
 
             bead_detect(output_path, overwrite=overwrite, fig=True)
+
+        if "bead_detect" in recipes:
+            logger.info("Running bead_detection recipe")
+            from ..beadlib import beads
+
+            beads(output_path, overwrite=overwrite)
+
     finally:
         cleanup(output_path)
 
