@@ -18,6 +18,11 @@ __config = {
     "sections": None,
     "channel_to_use": 3,
     "norm_val": 1,
+    "beads": {
+        "min_radius": 10,
+        "max_radius": 150,
+        "min_separation": 60,
+    },
 }
 
 _SettingsPlugin__config = __config
