@@ -39,6 +39,11 @@ __config = {
     "normal_x": 1000,
     "normal_y": 1000,
     "sections": None,
+    "beads": {
+        "min_radius": 60,
+        "max_radius": 150,
+        "min_separation": 60,
+    },
 }
 
 _SettingsPlugin__config = __config
