@@ -122,6 +122,12 @@ class GenericSection:
         Settings.y_min, Settings.y_max = y, yh
         Settings.x_min, Settings.x_max = x, xw
 
+        # Get channel to use with highest signal
+        med = json.loads(cals["flats"].attrs["median"])
+        med = list(med.values())
+        Settings.channel_to_use = np.argmax(med)
+        logger.debug("Using channel %d", Settings.channel_to_use)
+
     def calibrate(self, z, cals, persist=False):
         """Calibrate section"""
 
@@ -160,7 +166,27 @@ class GenericSection:
             res = persist_array(res, self.workers)
         return res
 
-    def calculate_offsets(self, images):
+    def initialize_grid(self, grid, avg_grid):
+        try:
+            grid2 = avg_grid
+            grid["left_ncc_first"] = grid2["left_ncc_first"]
+            grid["top_ncc_first"] = grid2["top_ncc_first"]
+            grid["left_x_first"] = grid2["left_x_first"]
+            grid["left_y_first"] = grid2["left_y_first"]
+            grid["top_x_first"] = grid2["top_x_first"]
+            grid["top_y_first"] = grid2["top_y_first"]
+            logger.debug("Read default positions")
+        except Exception:
+            grid["left_ncc_first"] = 1
+            grid["top_ncc_first"] = 1
+            grid["left_x_first"] = grid["left_x_init_guess"]
+            grid["left_y_first"] = grid["left_y_init_guess"]
+            grid["top_x_first"] = grid["top_x_init_guess"]
+            grid["top_y_first"] = grid["top_y_init_guess"]
+            logger.debug("Using microscope positions")
+        return grid
+
+    def calculate_offsets(self, images, avg_grid=None):
         stitcher = Stitcher(images, self.stagepos)
 
         # Downsample step
@@ -188,12 +214,7 @@ class GenericSection:
             stitcher.filter_grid(images, grid)
         except Exception:
             grid = stitcher.sp.grid.copy()
-            grid["left_ncc_first"] = 1
-            grid["top_ncc_first"] = 1
-            grid["left_x_first"] = grid["left_x_init_guess"]
-            grid["left_y_first"] = grid["left_y_init_guess"]
-            grid["top_x_first"] = grid["top_x_init_guess"]
-            grid["top_y_first"] = grid["top_y_init_guess"]
+            grid = self.initialize_grid(grid, avg_grid)
             stitcher.filter_grid(images, grid)
 
         stitcher.compute_second_pass(images, grid)
@@ -314,11 +335,14 @@ class GenericSection:
         def transform(im):
             nch, nz, ny, nx = im.shape
             if nx < 100:
-                return im[0, 0, : ny // 2, : nx // 2]
+                return im[:, :, : ny // 2, : nx // 2]
             res = []
             for ch in range(nch):
-                this = cv2.pyrDown(im[ch, 0].astype("float32")) / 0.9
-                res.append(this[None, ...])
+                zres = []
+                for z in range(nz):
+                    this = cv2.pyrDown(im[ch, z].astype("float32"))
+                    zres.append(this)
+                res.append(zres)
             return np.stack(res).astype("uint16")
 
         groups = ["", "l.2", "l.4", "l.8", "l.16", "l.32"]
